@@ -15,6 +15,7 @@ execfile(os.path.join(os.path.dirname(__file__),'setup_info.py'))
 
 __version__ = SETUP_INFO['version'] # 
 
+intersphinx_url = "http://north.lino-framework.org"
 
 #~ __author__ = "Luc Saffre <luc.saffre@gmx.net>"
 
@@ -97,13 +98,6 @@ class Site(Site):
     
     """
     
-    demo_fixtures = ['std','demo']
-    """
-    The list of fixtures to be loaded by the 
-    `initdb_demo <lino.management.commands.initdb_demo>`
-    command.
-    """
-    
     is_local_project_dir = False
     """
     This is automatically set when a :class:`Lino` is instantiated. 
@@ -161,11 +155,6 @@ class Site(Site):
     BABEL_LANGS = tuple()
     
     
-    def override_defaults(self,**kwargs):
-        super(Site,self).override_defaults(**kwargs)
-        self.apply_languages()
-    
-    
     def init_before_local(self,*args):
         super(Site,self).init_before_local(*args)
         self.update_settings(SERIALIZATION_MODULES = {
@@ -196,7 +185,11 @@ class Site(Site):
                 #~ self.update_settings(FIXTURE_DIRS = [pth])
                 
         
-        
+    def override_defaults(self,**kwargs):
+        super(Site,self).override_defaults(**kwargs)
+        self.apply_languages()
+    
+    
     def install_migrations(self,*args):
         """
         See :func:`north.dpy.install_migrations`.
@@ -209,10 +202,11 @@ class Site(Site):
         """
         
         """
-        for u in super(Site,self).using(ui): yield u
         import babel
+        
         yield ("Babel",babel.__version__,"http://babel.edgewall.org/")
         #~ yield (SETUP_INFO['name'],SETUP_INFO['version'],SETUP_INFO['url'])
+        for u in super(Site,self).using(ui): yield u
         
    
     def apply_languages(self):
@@ -272,6 +266,7 @@ class Site(Site):
         
         self.LANGUAGE_CHOICES = []
         self.LANGUAGE_DICT = dict() # used in lino.modlib.users
+        must_set_language_code = False
         
         #~ self.AVAILABLE_LANGUAGES = (to_locale(self.DEFAULT_LANGUAGE),)
         if self.languages is None:
@@ -289,8 +284,9 @@ class Site(Site):
             #~ lc = language_choices(*self._languages)
             #~ self.update_settings(LANGUAGES = lc)
             #~ self.update_settings(LANGUAGE_CODE = lc[0][0])
-            self.update_settings(LANGUAGE_CODE = self.languages[0])
+            #~ self.update_settings(LANGUAGE_CODE = self.languages[0])
             self.update_settings(USE_L10N = True)
+            must_set_language_code = True
           
         languages = []
         for i,django_code in enumerate(self.languages):
@@ -329,16 +325,21 @@ class Site(Site):
         #~ self.BABEL_LANGS = tuple([to_locale(code) for code in self.languages[1:]])
         self.BABEL_LANGS = tuple(self.languages[1:])
         #~ self.AVAILABLE_LANGUAGES = self.AVAILABLE_LANGUAGES + self.BABEL_LANGS
-            
                     
+        if must_set_language_code:
+            self.update_settings(LANGUAGE_CODE = self.get_default_language())
+        #~ self.update_settings(LANGUAGE_CODE = self.languages[0].django_code)
                     
 
     def do_site_startup(self):
-      
+        """
+        Called by :meth:`djangosite.Site.startup`.
+        """
         super(Site,self).do_site_startup()
         
         from django.conf import settings
         from django.utils.translation import ugettext_lazy as _
+        from north.dbutils import set_language
         
         def langtext(code):
             for k,v in settings.LANGUAGES:
@@ -380,6 +381,10 @@ class Site(Site):
                 text = _(text)
                 _add_language(lang.django_code,text)
                 
+            """
+            Activate the site's default language
+            """
+            set_language(self.get_default_language())
 
     def get_language_info(self,code):
         """
@@ -414,14 +419,53 @@ class Site(Site):
         #~ """
         #~ return self.DEFAULT_LANGUAGE
         
+    def resolve_languages(self,languages):
+        """
+        This is used by `UserProfile`.
         
+        Examples:
+        
+        >>> from north import TestSite as Site
+        >>> lst = Site(languages="en fr de nl et pt").resolve_languages('en fr')
+        >>> [i.name for i in lst]
+        ['en', 'fr']
+        
+        You may not specify languages which don't exist on this site:
+        
+        >>> Site(languages="en fr de").resolve_languages('en nl')
+        Traceback (most recent call last):
+        ...
+        Exception: Unknown language code 'nl' (must be one of ['en', 'fr', 'de'])
+        
+        
+        """
+        rv = []
+        if isinstance(languages,basestring):
+            languages = languages.split()
+        for k in languages:
+            if isinstance(k,basestring):
+                li = self.get_language_info(k)
+                if li is None:
+                    raise Exception("Unknown language code %r (must be one of %s)" % (
+                        k,[li.name for li in self.languages]))
+                rv.append(li)
+            else:
+                assert k in self.languages
+                rv.append(k)
+        return tuple(rv)
+                
     def language_choices(self,language,choices):
         l = choices.get(language,None)
         if l is None:
             l = choices.get(self.DEFAULT_LANGUAGE)
         return l
-
-
+        
+    def get_default_language(self):
+        """
+        The default language to use in every `north.dbutils.LanguageField`.
+        """
+        return self.DEFAULT_LANGUAGE.django_code
+        
     
 
     def babelkw(self,name,**kw):
@@ -517,7 +561,7 @@ class Site(Site):
         """
         #~ d = { self.DEFAULT_LANGUAGE.name : getattr(obj,name) }
         for lng in self.languages:
-            v = getattr(obj,name+lng.suffix)
+            v = getattr(obj,name+lng.suffix,None)
             if v:
                 known_values[lng.name] = v
         return known_values
@@ -683,3 +727,4 @@ class TestSite(Site):
     #~ def run_djangosite_local(self):
         #~ pass
         
+
