@@ -668,8 +668,8 @@ def install_migrations(self,globals_dict):
     and no migration, because this also does certain other things:
     
     - set :attr:`Site.loading_from_dump` to `True`
-    - remove any Permission and Site objects that have been 
-      generated by post_syncdb signal if these apps are installed.
+    - remove any Permission and Site objects that might have been 
+      generated by `post_syncdb` signal if these apps are installed.
     
     """
     
